==> austrakka-0.51.0-py3-none-any.whl: austrakka/components/project/provision/funcs.py <==
from typing import List
from loguru import logger
import pandas as pd
from austrakka.utils.api import api_patch, api_get
from austrakka.utils.misc import logger_wraps
from austrakka.utils.output import print_table
from austrakka.utils.paths import PROJECT_PATH


@logger_wraps()
def add_provision_project(abbrev: str, field_names: List[str]):
    field_name_objs = convert_to_api_dto(field_names)

    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/add-project-view-provision',
        data={
            "columnNames": field_name_objs
        }
    )


@logger_wraps()
def remove_project_provision(abbrev: str, provision_id: str):
    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/remove-project-view-provision/{provision_id}'
    )


@logger_wraps()
def update_project_provision(abbrev: str, provision_id: str, field_names: List[str]):
    field_name_objs = convert_to_api_dto(field_names)

    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/update-project-view-provision/{provision_id}',
        data={
            "columnNames": field_name_objs
        }
    )


@logger_wraps()
def get_dataset_provision_list(
        abbrev: str,
        out_format: str):
    path = "/".join([PROJECT_PATH, abbrev, 'project-provision-list'])
    response = api_get(path)
    data = response['data'] if ('data' in response) else response
    if not data:
        logger.info("No Dataset Provisions available")
        return

    result = pd.DataFrame.from_dict(data)
    print_table(
        result,
        out_format,
    )


def convert_to_api_dto(field_names):
    field_name_objs = []
    for field_name in field_names:
        field_name_objs.append({
            "ColumnName": field_name
        })
    return field_name_objs

==> austrakka-0.53.1-py3-none-any.whl: austrakka/components/project/provision/funcs.py <==
from typing import List
from loguru import logger
import pandas as pd
from austrakka.utils.api import api_patch, api_get
from austrakka.utils.misc import logger_wraps
from austrakka.utils.output import print_formatted
from austrakka.utils.paths import PROJECT_PATH


@logger_wraps()
def add_provision_project(abbrev: str, field_names: List[str]):
    field_name_objs = convert_to_api_dto(field_names)

    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/add-project-view-provision',
        data={
            "columnNames": field_name_objs
        }
    )


@logger_wraps()
def remove_project_provision(abbrev: str, provision_id: str):
    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/remove-project-view-provision/{provision_id}'
    )


@logger_wraps()
def update_project_provision(abbrev: str, provision_id: str, field_names: List[str]):
    field_name_objs = convert_to_api_dto(field_names)

    return api_patch(
        path=f'{PROJECT_PATH}/{abbrev}/update-project-view-provision/{provision_id}',
        data={
            "columnNames": field_name_objs
        }
    )


@logger_wraps()
def get_dataset_provision_list(
        abbrev: str,
        out_format: str):
    path = "/".join([PROJECT_PATH, abbrev, 'project-provision-list'])
    response = api_get(path)
    data = response['data'] if ('data' in response) else response
    if not data:
        logger.info("No Dataset Provisions available")
        return

    result = pd.DataFrame.from_dict(data)
    print_formatted(
        result,
        out_format,
    )


def convert_to_api_dto(field_names):
    field_name_objs = []
    for field_name in field_names:
        field_name_objs.append({
            "ColumnName": field_name
        })
    return field_name_objs
